# -*- coding: utf-8 -*-
"""
Created on Thu Nov 11 12:51:54 2021

@author: bnvanveldhuize
"""
import matplotlib.pyplot as plt
import matplotlib.cm as cm
import numpy as np
import pandas as pd

""" Operational point """
V = 0.8
FU = 0.8

""" Plot characteristics"""
fontsize1 = 14                  # for data labels
fontsize2 = 18                  # for axis titles
markersize = 10

""" Changing information per plot"""
choice = 2                      # Choose 1,2,3,4,5

parameter = [0,'Gross electric efficiency','Net electric efficiency','Heat efficiency','Total efficiency','Power density']
workbook = [0, "Gross_elec_eff","Net_elec_eff","Heat_eff","Tot_eff","P_i"]

excel_path_contour = "CT_output_hydrogen.xlsx"
df = pd.read_excel(excel_path_contour, workbook[choice], index_col = 0)

a = df.to_numpy()
min_tick = np.min(a[np.nonzero(a)])
max_tick = df.to_numpy().max()
ticks = [np.linspace(min_tick, max_tick,3)]

df = df.replace({0:np.nan})

# plt.figure(1)
# contours = plt.contour(df.columns,df.index, df, 10)
# plt.clabel(contours, inline=True, fontsize=8)
# plt.colorbar()
# plt.xlabel('FU [-]')
# plt.ylabel('V [V]')
# plt.savefig("contourplot1.png")


plt.figure(1, figsize=(12, 12), dpi=300)
contours = plt.contour(df.columns,df.index, df, 8, colors = 'black')     # plot contour lines

if choice == 1 or choice == 2 or choice == 3 or choice == 4:
    contours.collections[0].set_label(parameter[choice]+ ' [%]')
    plt.clabel(contours, inline=True, fmt='%1.1f' , fontsize=fontsize1)                                       # add label to contour lines
else:
    contours.collections[0].set_label(parameter[choice]+ r' $[A/m^2]$')
    plt.clabel(contours, inline=True, fmt='%1.0f' , fontsize=fontsize1)                                       # add label to contour lines

plt.contourf(df.columns,df.index, df, 800, colors = 'white')
plt.gca().set_facecolor("snow")
colormap = plt.contourf(df.columns,df.index, df, 800, cmap='RdYlGn', alpha=0.5)                # plot color map (800 lines to give continuous gradient)


plt.plot(FU, V, 'bo', markersize=markersize, label='Nominal operation')

cb = plt.colorbar(ticks = ticks)
cb.ax.tick_params(labelsize = fontsize1)
plt.xlabel('Fuel utilisation [-]', fontsize = fontsize2)
plt.ylabel('Voltage [V]', fontsize = fontsize2)
plt.tick_params(axis='both', which='major', labelsize=fontsize1)
plt.grid(color = 'gray', linestyle=(0, (5, 10)), linewidth=1)
plt.legend(fontsize=fontsize2, loc = 'upper center')
plt.show
plt.savefig("contourplot " + parameter[choice] + " (V and FU)" +".png", bbox_inches='tight',pad_inches = 0.1)

print("Script is finished")
